#include <bsp.h>
//------------------------------------------------------------------------------
//
//  Function:  OALArgsInit
//
//  This function is called by other OAL modules to intialize value of argument
//  structure.
//
VOID OALArgsInit(BSP_ARGS* pArgs)
{
    OALMSG(0, (TEXT("+OALArgsInit()\r\n")));

    // Check the BSP Args area
    //
    if ((pArgs->header.signature  == OAL_ARGS_SIGNATURE)
        || (pArgs->header.oalVersion == OAL_ARGS_VERSION)
        || (pArgs->header.bspVersion == BSP_ARGS_VERSION))
    {
        RETAILMSG(TRUE , (L"Device ID : %hs.\r\n", pArgs->deviceId));
    }
    else
    {
        memset(pArgs, 0x0, sizeof(BSP_ARGS));

        // Setup header
	    pArgs->header.signature       = OAL_ARGS_SIGNATURE;
	    pArgs->header.oalVersion      = OAL_ARGS_VERSION;
	    pArgs->header.bspVersion      = BSP_ARGS_VERSION;
	    pArgs->kitl.flags             = OAL_KITL_FLAGS_ENABLED | OAL_KITL_FLAGS_VMINI;
	    pArgs->kitl.devLoc.IfcType    = Internal;
	    pArgs->kitl.devLoc.BusNumber  = 0;
	    pArgs->kitl.devLoc.LogicalLoc = BSP_BASE_REG_PA_CS8900A_IOBASE;

        // Can Add code for cleanboot, hiveclean, formatpartion
        OALMSG(TRUE, (TEXT("Arguments area is initialized\r\n")));
    }

    OALMSG(0, (TEXT("-OALArgsInit()\r\n")));

    return;
}


//------------------------------------------------------------------------------
//
//  Function:  OALArgsQuery
//
//  This function is called from other OAL modules to return boot arguments.
//  Boot arguments are typically placed in fixed memory location and they are
//  filled by boot loader. In case that boot arguments can't be located
//  the function should return NULL. The OAL module then must use default
//  values.
//


VOID* OALArgsQuery(UINT32 type)
{
    VOID *pData = NULL;
    BSP_ARGS *pArgs;
    UINT8 tmpUUID[16]={0x00,0x11,0x22,0x33,0x44,0x55,0x66,0x77,0x88,0x99,0xaa,0xbb,0xcc,0xdd,0xee,0xff};

    OALMSG(OAL_ARGS&&OAL_FUNC, (L"+OALArgsQuery(%d)\r\n", type));

	if(type == OAL_ARGS_QUERY_UUID)
	{
		// Get your own uuid from here
		pData = &tmpUUID;
	}

    // Get pointer to expected boot args location
    pArgs = (BSP_ARGS*)IMAGE_SHARE_ARGS_UA_START;

    // Check if there is expected signature
    if (
        pArgs->header.signature  != OAL_ARGS_SIGNATURE ||
        pArgs->header.oalVersion != OAL_ARGS_VERSION   ||
        pArgs->header.bspVersion != BSP_ARGS_VERSION
    ) {
    	OALMSG(1, (L"OALArgsQuery()  Signature or Version Not Match.\r\n"));
    	goto cleanUp;
    }

    // Depending on required args
    switch (type) {
    case OAL_ARGS_QUERY_DEVID:
        pData = &pArgs->deviceId;
        break;
    case OAL_ARGS_QUERY_KITL:
        pData = &pArgs->kitl;
        break;
    }

cleanUp:
    OALMSG(OAL_ARGS&&OAL_FUNC, (L"-OALArgsQuery(pData = 0x%08x)\r\n", pData));
    return pData;
}

//------------------------------------------------------------------------------

